==> linstor-server-1.15.0.tar.gz: linstor-server-1.15.0/server/src/main/java/com/linbit/linstor/core/objects/Remote.java <==
package com.linbit.linstor.core.objects;

import com.linbit.linstor.core.identifier.RemoteName;
import com.linbit.linstor.dbdrivers.DatabaseException;
import com.linbit.linstor.security.AccessContext;
import com.linbit.linstor.security.AccessDeniedException;
import com.linbit.linstor.stateflags.FlagsHelper;
import com.linbit.linstor.stateflags.StateFlags;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

public interface Remote
{
    RemoteName getName();

    void delete(AccessContext apiCtxRef) throws AccessDeniedException, DatabaseException;

    UUID getUuid();

    StateFlags<Flags> getFlags();

    RemoteType getType();

    public enum Flags implements com.linbit.linstor.stateflags.Flags
    {
        DELETE(1L),
        S3_USE_PATH_STYLE(1L << 1);

        public final long flagValue;

        Flags(long value)
        {
            flagValue = value;
        }

        @Override
        public long getFlagValue()
        {
            return flagValue;
        }

        public static Flags[] valuesOfIgnoreCase(String string)
        {
            Flags[] flags;
            if (string == null)
            {
                flags = new Flags[0];
            }
            else
            {
                String[] split = string.split(",");
                flags = new Flags[split.length];

                for (int idx = 0; idx < split.length; idx++)
                {
                    flags[idx] = Flags.valueOf(split[idx].toUpperCase().trim());
                }
            }
            return flags;
        }

        public static Flags[] restoreFlags(long remoteFlags)
        {
            List<Flags> flagList = new ArrayList<>();
            for (Flags flag : Flags.values())
            {
                if ((remoteFlags & flag.flagValue) == flag.flagValue)
                {
                    flagList.add(flag);
                }
            }
            return flagList.toArray(new Flags[flagList.size()]);
        }

        public static List<String> toStringList(long flagsMask)
        {
            return FlagsHelper.toStringList(Flags.class, flagsMask);
        }

        public static long fromStringList(List<String> listFlags)
        {
            return FlagsHelper.fromStringList(Flags.class, listFlags);
        }
    }

    public enum RemoteType
    {
        S3,
        SATELLTE,
        LINSTOR // controller only, should never be sent to satellite
    }
}

==> linstor-server-1.18.1-rc.1.tar.gz: linstor-server-1.18.1-rc.1/server/src/main/java/com/linbit/linstor/core/objects/Remote.java <==
package com.linbit.linstor.core.objects;

import com.linbit.linstor.core.identifier.RemoteName;
import com.linbit.linstor.dbdrivers.DatabaseException;
import com.linbit.linstor.security.AccessContext;
import com.linbit.linstor.security.AccessDeniedException;
import com.linbit.linstor.stateflags.FlagsHelper;
import com.linbit.linstor.stateflags.StateFlags;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

public interface Remote
{
    RemoteName getName();

    void delete(AccessContext apiCtxRef) throws AccessDeniedException, DatabaseException;

    UUID getUuid();

    StateFlags<Flags> getFlags();

    RemoteType getType();

    enum Flags implements com.linbit.linstor.stateflags.Flags
    {
        DELETE(1L),
        S3_USE_PATH_STYLE(1L << 1);

        public final long flagValue;

        Flags(long value)
        {
            flagValue = value;
        }

        @Override
        public long getFlagValue()
        {
            return flagValue;
        }

        public static Flags[] valuesOfIgnoreCase(String string)
        {
            Flags[] flags;
            if (string == null)
            {
                flags = new Flags[0];
            }
            else
            {
                String[] split = string.split(",");
                flags = new Flags[split.length];

                for (int idx = 0; idx < split.length; idx++)
                {
                    flags[idx] = Flags.valueOf(split[idx].toUpperCase().trim());
                }
            }
            return flags;
        }

        public static Flags[] restoreFlags(long remoteFlags)
        {
            List<Flags> flagList = new ArrayList<>();
            for (Flags flag : Flags.values())
            {
                if ((remoteFlags & flag.flagValue) == flag.flagValue)
                {
                    flagList.add(flag);
                }
            }
            return flagList.toArray(new Flags[flagList.size()]);
        }

        public static List<String> toStringList(long flagsMask)
        {
            return FlagsHelper.toStringList(Flags.class, flagsMask);
        }

        public static long fromStringList(List<String> listFlags)
        {
            return FlagsHelper.fromStringList(Flags.class, listFlags);
        }
    }

    enum RemoteType
    {
        S3,
        SATELLTE,
        LINSTOR // controller only, should never be sent to satellite
    }
}
